@@ -8,5 +8,4 @@ class _SessionMetadataApi(_ApiSupport):
 
     def filter_app_session_metadata(self, org_uuid, app_id):
         path = '{org_uuid}/metadata/session/{app_id}/filters'.format(org_uuid=org_uuid, app_id=app_id)
-        no_filter = {}
-        return self._post(path,data=no_filter)
+        return self._post(path, json={})
